@@ -20,6 +20,10 @@
 #include <sys/stat.h>
 #include <sys/event.h>
 
+#if defined(_MACOS_PORT)
+#include <sys/sysctl.h>
+#endif
+
 #include <dirent.h>
 #include <err.h>
 #include <errno.h>
@@ -102,8 +106,8 @@ main(int argc, char *argv[]) {
 	struct kevent evSet;
 	unsigned open_max;
 
-	 if (pledge("stdio rpath tty proc exec", NULL) == -1)
-	    err(1, "pledge");
+	if (pledge("stdio rpath tty proc exec", NULL) == -1)
+		err(1, "pledge");
 
 	/* call usage() if no command is supplied */
 	if (argc < 2) usage();
@@ -135,14 +139,11 @@ main(int argc, char *argv[]) {
 #elif defined(_MACOS_PORT)
 	if (getrlimit(RLIMIT_NOFILE, &rl) == -1)
 		err(1, "getrlimit");
-	/* guard against unrealistic replies */
-	open_max = min(65536, (unsigned)rl.rlim_cur);
-	/* maxfiles is ulimited on modern MacOS */
-	if (open_max < 65536) {
-		rl.rlim_cur = (rlim_t)65536;
-		if (setrlimit(RLIMIT_NOFILE, &rl) == 0 || open_max == 0)
-			open_max = 65536;
-	}
+	size_t len = sizeof(open_max);
+	sysctlbyname("kern.maxfilesperproc", &open_max, &len, NULL, 0);
+	rl.rlim_cur = (rlim_t)open_max;
+	if (setrlimit(RLIMIT_NOFILE, &rl) != 0)
+		err(1, "setrlimit cannot set rlim_cur to %u", open_max);
 #else /* BSD */
 	if (getrlimit(RLIMIT_NOFILE, &rl) == -1)
 		err(1, "getrlimit");
@@ -245,9 +246,9 @@ handle_exit(int sig) {
 	terminate_utility();
 
 	if ((sig == SIGINT || sig == SIGHUP))
-	    _exit(0);
+		_exit(0);
 	else
-	    raise(sig);
+		raise(sig);
 }
 
 void
@@ -505,23 +506,28 @@ run_utility(char *argv[]) {
 void
 watch_file(int kq, WatchFile *file) {
 	struct kevent evSet;
-	int i;
+	int i = 0;
 	struct timespec delay = { 0, 100 * 1000000 };
 
 	/* wait up to 1 second for file to become available */
-	for (i=0; i < 10; i++) {
+	for (;;) {
 		#ifdef O_EVTONLY
 		file->fd = open(file->fn, O_RDONLY|O_CLOEXEC|O_EVTONLY);
 		#else
 		file->fd = open(file->fn, O_RDONLY|O_CLOEXEC);
 		#endif
-		if (file->fd == -1) nanosleep(&delay, NULL);
-		else break;
-	}
-	if (file->fd == -1) {
-		warn("cannot open '%s'", file->fn);
-		terminate_utility();
-		exit(1);
+		if (file->fd == -1) {
+			if (i < 10)
+				nanosleep(&delay, NULL);
+			else {
+				warn("cannot open '%s'", file->fn);
+				terminate_utility();
+				exit(1);
+			}
+		}
+		else
+			break;
+		i++;
 	}
 
 	EV_SET(&evSet, file->fd, EVFILT_VNODE, EV_ADD | EV_CLEAR, NOTE_ALL, 0,
